@@ -49,6 +49,8 @@ BayonneBinder("ivrscript1")
                         (Check)&Checks::chkAssign},  
                 {"assign", false, (Method)&ScriptMethods::scrNop,
                         (Check)&Checks::chkAssign},    
+                {"_keydata_", false, (Method)&Methods::scrKeydata,
+                        (Check)&Checks::chkKeydata},
                 {"register", false, (Method)&ScriptMethods::scrNop,
                         (Check)&Checks::chkRegister},
                 {"extern", false, (Method)&ScriptMethods::scrNop,
