@@ -207,6 +207,9 @@ const char *Checks::chkRegister(Line *line, ScriptImage *img)
 	if(scr->access != ScriptInterp::scrPUBLIC)
 		return "cannot register non-public script";
 
+	if(scr->first && !stricmp(scr->first->cmd, "_keydata_"))
+		return "cannot add additional registration to this entry";
+
 	if(ext && !stricmp(ext, ".conf"))
 	{
 		if(cp)
@@ -237,7 +240,41 @@ const char *Checks::chkRegister(Line *line, ScriptImage *img)
 	}
 	return driver->registerScript(img, line);
 }
-	
+
+const char *Checks::chkKeydata(Line *line, ScriptImage *img)
+{
+	Name *scr = img->getCurrent();
+	BayonneDriver *driver;
+	const char *cp;
+	char dbuf[15];
+	char *sp;
+
+	if(scr->access != ScriptInterp::scrPUBLIC)
+		return "cannot register non-public script";
+
+	cp = strrchr(scr->filename, '/');
+	if(cp)
+		++cp;
+	else
+		cp = scr->filename;
+
+	setString(dbuf, sizeof(dbuf), cp);
+	sp = strchr(dbuf, '.');
+	if(sp)
+		*sp = 0;
+	driver = BayonneDriver::get(dbuf);
+
+	if(!driver)
+	{
+		slog.warn("cannot register keydata %s with driver", scr->name);
+		return "";
+	}
+	cp = driver->registerScript(img, line);
+	if(cp && *cp)
+		return cp;
+	return NULL;
+}
+
 const char *Checks::chkAssign(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
@@ -248,6 +285,9 @@ const char *Checks::chkAssign(Line *line, ScriptImage *img)
 	BayonneSession *s;
 	const char *ext = strrchr(scr->filename, '.');
 
+	if(scr->first && !stricmp(scr->first->cmd, "_keydata_"))
+		return "cannot add assignment to this entry";
+
 	if(ext && !stricmp(ext, ".conf"))
 		return "assign not used in config";
 
