@@ -83,6 +83,33 @@ bool Methods::scrRelease(void)
 	return true;
 }
 
+bool Methods::scrKeydata(void)
+{
+	Line *line = getLine();
+	const char *ext = getSymbol("session.identity");
+
+	if(isAssociated() && ext && *ext)
+	{
+		redirect("connect::incoming");
+		return false;
+	}
+	
+	if(isAssociated())
+	{
+		redirect("connect::outgoing");
+		return false;
+	}
+
+	if(!line->next)
+	{
+		redirect("connect::common");
+		return false;
+	}
+
+	advance();
+	return true;
+}	
+
 bool Methods::scrRedial(void)
 {
 	Name *scr = NULL;
