@@ -94,6 +94,7 @@ class Checks : public ScriptChecks, public Bayonne
 public:
         const char *chkCDR(Line *line, ScriptImage *img); 
         const char *chkRegister(Line *line, ScriptImage *img);
+		const char *chkKeydata(Line *line, ScriptImage *img);
         const char *chkAssign(Line *line, ScriptImage *img);
         const char *chkSelect(Line *line, ScriptImage *img);   
         const char *chkKey(Line *line, ScriptImage *img);  
@@ -113,6 +114,7 @@ public:
 class Methods : public BayonneSession
 {
 public:
+	bool scrKeydata(void);
 	bool scrKey(void);
 	bool scrRing(void);
 	bool scrRelease(void);
