@@ -1354,13 +1354,19 @@ challenge:
 	eXosip_unlock();
 }
 
+#ifdef	SCRIPT_RIPPLE_KEYDATA
+#define	regKeyword(l, k)	ScriptChecks::findKeyword(img, l, k)
+#else
+#define	regKeyword(l, k)	ScriptChecks::findKeyword(l, k)
+#endif
+
 const char *Driver::registerScript(ScriptImage *img, Line *line)
 {
 	Name *scr = img->getCurrent();
 	Registry *reg = (Registry *)img->getMemory(sizeof(Registry));
 	Registry *preg;
-        const char *dur = ScriptChecks::findKeyword(line, "timeout");
-	const char *insecure = ScriptChecks::findKeyword(line, "insecure");
+	const char *dur = regKeyword(line, "timeout");
+	const char *insecure = regKeyword(line, "insecure");
 	const char *lcp, *cp;
 	char buf[1024];
 	char nbuf[32];
@@ -1397,41 +1403,50 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 
 	reg->protocol = "sip";
 	reg->iface = getLast("interface");
-	reg->uri = ScriptChecks::findKeyword(line, "uri");
-	reg->address = ScriptChecks::findKeyword(line, "public");
-	reg->hostid = ScriptChecks::findKeyword(line, "proxy");
-	reg->userid = ScriptChecks::findKeyword(line, "userid");
-	reg->secret = ScriptChecks::findKeyword(line, "secret");
-	reg->realm = ScriptChecks::findKeyword(line, "realm");
-	reg->type = ScriptChecks::findKeyword(line, "type");
-	reg->dtmf = ScriptChecks::findKeyword(line, "dtmf");
-	reg->peering = ScriptChecks::findKeyword(line, "peering");
-	reg->encoding = ScriptChecks::findKeyword(line, "encoding");
-	reg->caller = ScriptChecks::findKeyword(line, "caller");
-	reg->reconnect = ScriptChecks::findKeyword(line, "reconnect");
-	reg->answer = ScriptChecks::findKeyword(line, "answer");
-	reg->update = ScriptChecks::findKeyword(line, "update");
-	reg->hold = ScriptChecks::findKeyword(line, "hold");
-	reg->transfer = ScriptChecks::findKeyword(line, "transfer");
-	reg->group = ScriptChecks::findKeyword(line, "group");
-	gateways = ScriptChecks::findKeyword(line, "gateways");
+	reg->uri = regKeyword(line, "uri");
+	reg->address = regKeyword(line, "public");
+	reg->hostid = regKeyword(line, "proxy");
+	reg->userid = regKeyword(line, "userid");
+	reg->secret = regKeyword(line, "secret");
+	reg->realm = regKeyword(line, "realm");
+	reg->type = regKeyword(line, "type");
+	reg->dtmf = regKeyword(line, "dtmf");
+	reg->peering = regKeyword(line, "peering");
+	reg->encoding = regKeyword(line, "encoding");
+	reg->caller = regKeyword(line, "caller");
+	reg->reconnect = regKeyword(line, "reconnect");
+	reg->answer = regKeyword(line, "answer");
+	reg->update = regKeyword(line, "update");
+	reg->hold = regKeyword(line, "hold");
+	reg->transfer = regKeyword(line, "transfer");
+	reg->group = regKeyword(line, "group");
+	gateways = regKeyword(line, "gateways");
+
+	if(!stricmp(line->cmd, "_keydata_"))
+	{
+		if(reg->type && !strnicmp(reg->type, "ext", 3))
+			ext = true;
+		else if(reg->type && !stricmp(reg->type, "gateway"))
+			gw = true;
+	}
 		
 	if(!reg->group)
 		reg->group = "nobody";
 
-	cp = ScriptChecks::findKeyword(line, "accept");
+	cp = regKeyword(line, "accept");
 	if(cp)
 		reg->accept = atol(cp);
 
 	if(ext || gw)
-		reg->localid = ScriptChecks::findKeyword(line, "user");
+		reg->localid = regKeyword(line, "user");
 	if(gw && !reg->localid)
-		reg->localid = ScriptChecks::findKeyword(line, "userid");
+		reg->localid = regKeyword(line, "userid");
 
 	if(!ext)
 	{
-		reg->service = ScriptChecks::findKeyword(line, "service");
-		reg->localid = ScriptChecks::findKeyword(line, "local");
+		reg->service = regKeyword(line, "service");
+		reg->localid = regKeyword(line, "local");
+
 		if(reg->service && !reg->localid)
 			reg->localid = reg->service;
 	}
@@ -1455,21 +1470,21 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 			reg->service += 5;
 	}
 
-	cp = ScriptChecks::findKeyword(line, "limit");
+	cp = regKeyword(line, "limit");
 	if(cp)
 		reg->call_limit = atoi(cp);
-	cp = ScriptChecks::findKeyword(line, "count");
+	cp = regKeyword(line, "count");
 	if(cp)
 		reg->call_limit = atoi(cp);
 
-	cp = ScriptChecks::findKeyword(line, "framing");
+	cp = regKeyword(line, "framing");
 
 	if(!cp || !reg->encoding)
 		cp = "0";
 	reg->framing = atol(cp);
 	
 #ifndef	WIN32
-	cp = ScriptChecks::findKeyword(line, "device");
+	cp = regKeyword(line, "device");
 	if(cp)
 	{
 		snprintf(buf, sizeof(buf), "/bayonne/device/%s", cp);
@@ -1585,7 +1600,7 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 		reg->dtmf = "auto";
 
 	if(!reg->hostid || !*reg->hostid)
-		reg->hostid = ScriptChecks::findKeyword(line, "server");
+		reg->hostid = regKeyword(line, "server");
 
 	if(!reg->hostid || !*reg->hostid)
 	{
@@ -1776,7 +1791,7 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 		eXosip_transport_set(msg, "TLS");
 
 /*
-	reg->route = ScriptChecks::findKeyword(line, "route");
+	reg->route = regKeyword(line, "route");
 	if(reg->route && reg->route[0])
 	{
 		char *hdr = osip_strdup(reg->route);
