@@ -39,7 +39,7 @@ static Snapshot snapshot;
 Snapshot::Snapshot() :
 BayonneService(0, 0), TimerPort()
 {
-	const char *runpath = Bayonne::server->getLast("runfiles");
+	const char *runpath = server->getLast("runfiles");
 
 	snprintf(runfile, sizeof(runfile), "%s/bayonne.info", runpath);
 	snprintf(tmpfile, sizeof(tmpfile), "%s/.bayonne.info", runpath);
