@@ -87,10 +87,6 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 	cp = getLast("gain");
 	if(cp)
 		gain = atof(cp);
-
-	server->setValue("trunk.conf", CONFIG_FILES "/trunk.conf");
-	server->setValue("timeslot.conf", CONFIG_FILES "/timeslot.conf");
-	server->setValue("caller.conf", CONFIG_FILES "/caller.conf");
 }
 
 void Driver::startDriver(void)
