@@ -27,7 +27,7 @@ unsigned long Session::htmlAccess(const char *fname)
 {
 	char path[256];
 	struct stat ino;
-	const char *prefix = Service::webservice.getLast("datafiles");
+	const char *prefix = Service::webservice.getString("datafiles");
 
 	snprintf(path, sizeof(path), "%s/%s", prefix, fname);
 
@@ -43,7 +43,7 @@ void Session::htmlInsert(const char *path, const char *title)
 	FILE *fp;
 	const char *cp;
 	char *dp = buffer;
-	const char *prefix = Service::webservice.getLast("datafiles");
+	const char *prefix = Service::webservice.getString("datafiles");
         const char *sl = sla;
         unsigned long upt = uptime();
         char dur[65];
@@ -148,7 +148,7 @@ void Session::htmlHeader(const char *title, bool refresh)
 	{
 		snprintf(buffer, sizeof(buffer),
 			"<META HTTP-EQUIV=Refresh CONTENT=\"%s\"/>\r\n",
-			Service::webservice.getLast("refresh"));
+			Service::webservice.getString("refresh"));
 		sendText(buffer);
 	}
 	sendText("</HEAD>\r\n");
