@@ -54,7 +54,7 @@ void Session::xmlFault(int code, const char *string)
 	int fd;
 
         snprintf(buffer, sizeof(buffer), "%s/web.errors",
-	        Service::webservice.getLast("logfiles"));
+	        Service::webservice.getString("logfiles"));
 
 #ifndef	WIN32
 	fd = ::open(buffer, O_CREAT | O_APPEND);
