@@ -117,9 +117,9 @@ static Keydata::Define urlkeys[] = {
 bool flag_daemon = false;
 bool flag_check = false;
 
-Keydata keypaths(paths, "/bayonne/server/paths");
-Keydata keyserver(server, "/bayonne/server/server");
-Keydata keyengine(engine, "/bayonne/server/engine");
+StaticKeydata keypaths("/bayonne/server/paths", paths);
+StaticKeydata keyserver("/bayonne/server/server", server);
+StaticKeydata keyengine("/bayonne/server/engine", engine);
 BayonneConfig keylibexec("libexec", libkeys, "/bayonne/server/libexec");
 BayonneConfig keysmtp("smtp", smtpkeys, "/bayonne/server/smtp");
 BayonneConfig keyurl("url", urlkeys, "/bayonne/server/url");
@@ -128,15 +128,26 @@ Keydata keyoptions;
 
 void liveConfig(void)
 {
+	const char *cfgid = Process::getEnv("BAYONNE_CONFIG");
+
 	char path[256];
 	char lang[32];
 	const char *env;
 	char *p, *sp, *tok;
-	const char *cp;
+	const char *cp = cfgid;
 	bool ttsdef = false, libdef = false;
 	unsigned timeslots = atoi(keyengine.getLast("timeslots"));
 	Bayonne::timeslot_t overdraft = 1;
 
+	while(cp && *cp && isalnum(*cp))
+		++cp;
+
+	if(cp && *cp)
+	{
+		slog.critical("invalid config in environment");
+		exit(-1);
+	}
+
 #ifdef	WIN32
         char nodename[MAX_COMPUTERNAME_LENGTH + 1];
         DWORD namelen = MAX_COMPUTERNAME_LENGTH + 1;
@@ -158,6 +169,9 @@ void liveConfig(void)
         GetVersionEx(&osver);
         GetComputerName(nodename, &namelen);
         keyserver.setValue("node", nodename);
+		if(cfgid)
+			keyserver.setValue("node", cfgid);
+
         GetSystemInfo(&sysinfo);
         switch(sysinfo.wProcessorArchitecture)
         {
@@ -190,8 +204,13 @@ void liveConfig(void)
 		*hp = 0;
 
 	if(!keyserver.getLast("node"))
-		keyserver.setValue("node", hostname);
-	
+	{
+		if(cfgid)
+			keyserver.setValue("node", cfgid);
+		else
+			keyserver.setValue("node", hostname);
+	}
+
 	keyserver.setValue("platform", uts.sysname);
 	keyserver.setValue("cpu", uts.machine);
 	userid = getenv("USER");
@@ -199,14 +218,17 @@ void liveConfig(void)
 	if(!userid || !stricmp(userid, "root"))
 		userid="bayonne";	
 
-	snprintf(path, sizeof(path), "/tmp/bayonne-%s", userid);
+	if(!cfgid)
+		cfgid = userid;
+
+	snprintf(path, sizeof(path), "/tmp/bayonne-%s", cfgid);
 	keypaths.setValue("tmp", path);
 	purgedir(path);
 	Dir::create(path);
 
 	if(canModify("/dev/shm"))
 	{
-		snprintf(path, sizeof(path), "/dev/shm/bayonne-%s", userid);
+		snprintf(path, sizeof(path), "/dev/shm/bayonne-%s", cfgid);
 		keypaths.setValue("tmpfs", path);
 		purgedir(path);
 		Dir::create(path);
@@ -214,7 +236,17 @@ void liveConfig(void)
 	else
 		keypaths.setValue("tmpfs", path);
 
+	if(cfgid == userid)
+		cfgid = NULL;
+
 #endif
+	if(cfgid)
+	{
+		snprintf(path, sizeof(path), "%s-%s", CONFIG_FILES, cfgid);
+		keypaths.setValue("config", path);
+		snprintf(path, sizeof(path), "%s-%s", RUN_FILES, cfgid);
+		keypaths.setValue("runfiles", path);
+	}
         sp = (char *)keyserver.getLast("definitions");
 
 	if(sp && !stricmp(sp, "default"))
@@ -340,7 +372,6 @@ void liveConfig(void)
                 keypaths.getLast("logfiles"), keyserver.getLast("node"));
         runtime.setValue("stats", path);
 
-	runtime.setValue("runlevel.conf", CONFIG_FILES "/runlevel.conf");
 	runtime.setValue("include", keypaths.getLast("macros"));
 	keypaths.setValue("include", keypaths.getLast("macros"));
 	runtime.setValue("tmp", keypaths.getLast("tmp"));
@@ -424,19 +455,6 @@ void loadConfig(void)
 	char pbuf[256];
 	const char *config = keypaths.getLast("config");
 
-	snprintf(pbuf, sizeof(pbuf), "%s/server.ini", config); 
-	keypaths.loadFile(pbuf, "paths");
-	keyserver.loadFile(pbuf, "server");
-	keyengine.loadFile(pbuf, "engine");
-	keylibexec.loadFile(pbuf, "libexec");
-	keysmtp.loadFile(pbuf, "smtp");
-	keyurl.loadFile(pbuf, "url");
-
-	snprintf(pbuf, sizeof(pbuf), "%s/driver.ini", config);
-	Process::setEnv("DRIVERCONFIG", pbuf, true); 
-	snprintf(pbuf, sizeof(pbuf), "%s/module.ini", config);
-	Process::setEnv("MODULECONFIG", pbuf, true);
-
 //	Process::setGroup(keyserver.getLast("group"));
         Dir::create(keypaths.getLast("datafiles"));
         Dir::create(keypaths.getLast("runfiles"));
@@ -457,15 +475,6 @@ void loadConfig(void)
 	else
 		strcpy(homepath, "tempfiles");
 
-	if(Bayonne::getUserdata())
-	{
-		keypaths.load("~bayonne/paths");
-		keyserver.load("~bayonne/server");
-		keyengine.load("~bayonne/engine");
-		keysmtp.load("~bayonne/smtp");
-		keyurl.load("~bayonne/url");
-	}
-
 	umask(007);
 	Process::setGroup(keyserver.getLast("group"));
 	Dir::create(keypaths.getLast("datafiles"));
