@@ -45,9 +45,10 @@ bool Methods::scrSay(void)
 	const char *file = getKeyword("file");
 	const char *opt;
 	unsigned len = 0;
+	char keybuf[65];
 
 	snprintf(buf, sizeof(buf), "definitions::tts-%s", 
-		keylibexec.getLast("tts"));
+		keylibexec.getString("tts", keybuf, sizeof(keybuf)));
 
 	tts = getScript(buf);
 	if(!tts)
@@ -57,7 +58,7 @@ bool Methods::scrSay(void)
 	}
 
 	if(!voice)
-		voice = keylibexec.getLast("voice");
+		voice = keylibexec.getString("voice", keybuf, sizeof(keybuf));
 
 	while((NULL != (opt = getValue(NULL))) && (len < (sizeof(buf) - 2)))
 	{
@@ -90,7 +91,7 @@ bool Methods::scrSay(void)
 		setConst("extension", ext);
 	if(file)
 		setConst("file", file);
-	setConst("limit", keylibexec.getLast("ttslimit"));
+	setConst("limit", keylibexec.getString("ttslimit", keybuf, sizeof(keybuf)));
 	return true;
 }
 
@@ -494,7 +495,7 @@ bool Methods::scrSRoute(void)
 	char evt[65];
 	
 	if(!cp)
-		cp = "digits";
+		cp = "string";
 
 	setSymbol("script.error", "none");
 
