@@ -185,6 +185,7 @@ ScriptRuntime()
 
 	load(interp);
 
+	ScriptInterp::addConditional("runlevel", &testLevel);
 	ScriptInterp::addConditional("file", &testFile);
 	ScriptInterp::addConditional("dir", &testDir);
 	ScriptInterp::addConditional("span", &testSpan);
@@ -254,7 +255,7 @@ const char *Runtime::getExternal(const char *opt)
 
 void Runtime::errlog(const char *level, const char *msg)
 {
-        const char *path = keypaths.getLast("errlog");
+        const char *path = getLast("errlog");
 	char buffer[256];
 	char *m;
         struct tm *dt, tbuf;
@@ -461,6 +462,14 @@ bool Runtime::testVoice(ScriptInterp *interp, const char *v)
 	return (s->audio.getVoicelib(v) != NULL);
 }
 
+bool Runtime::testLevel(ScriptInterp *interp, const char *v)
+{
+	if(!stricmp(v, Bayonne::getRunLevel()))
+		return true;
+
+	return false;
+}
+
 bool Runtime::testLang(ScriptInterp *interp, const char *v)
 {
 	BayonneSession *s = (BayonneSession *)(interp);
