@@ -198,6 +198,7 @@ protected:
 	static bool testDriver(ScriptInterp *interp, const char *v);
 	static bool testVoice(ScriptInterp *interp, const char *v);
 	static bool testLang(ScriptInterp *interp, const char *v);
+	static bool testLevel(ScriptInterp *interp, const char *v);
 
 public:
 	static void process(void);
@@ -303,9 +304,9 @@ public:
 };
 
 extern Runtime runtime;
-extern Keydata keypaths;
-extern Keydata keyserver;
-extern Keydata keyengine;
+extern StaticKeydata keypaths;
+extern StaticKeydata keyserver;
+extern StaticKeydata keyengine;
 extern Keydata keyoptions;
 extern BayonneConfig keylibexec;
 extern BayonneConfig keysmtp;
